# Qovery Resource Provider

The Qovery Resource Provider lets you manage [Qovery](https://qovery.com/) resources.

## Installing

This package is available for several languages/platforms:

### Node.js (JavaScript/TypeScript)

To use from JavaScript or TypeScript in Node.js, install using either `npm`:

```bash
npm install@ediri/qovery
```

or `yarn`:

```bash
yarn add @ediri/qovery
```

### Python

To use from Python, install using `pip`:

```bash
pip install ediri_qovery
```

### Go

To use from Go, use `go get` to grab the latest version of the library:

```bash
go get github.com/dirien/pulumi-qovery/sdk/go/...
```

### .NET

To use from .NET, install using `dotnet add package`:

```bash
dotnet add package ediri.Qovery
```

## Configuration

The following configuration points are available for the `qovery` provider:

- `token` (String) The Qovery API Token to use. This can also be specified with the `QOVERY_API_TOKEN` shell environment variable.

## Reference

For detailed reference documentation, please visit [the Pulumi registry](https://www.pulumi.com/registry/packages/qovery/api-docs/).
